"""Configuration from environment variables."""
import os

API_KEY = os.getenv("RELAYWAY_API_KEY")
WEBHOOK_SECRET = os.getenv("RELAYWAY_WEBHOOK_SECRET")
BASE_URL = os.getenv("RELAYWAY_BASE_URL", "http://localhost:8000")
